@@ -22,7 +22,120 @@ from gtweak.widgets import ListBoxTweakGroup, GSettingsComboEnumTweak, GSettings
 from gtweak.utils import XSettingsOverrides
 import gettext
 
-from gi.repository import Gtk, GLib
+from gi.repository import Gio, Gtk, GLib
+
+
+class Focus(Gtk.ListBox, Tweak):
+
+    def __init__(self, **options):
+        Gtk.ListBox.__init__(self)
+        Tweak.__init__(self, _("Window Focus"), _("Click to Focus"))
+
+        self.settings = Gio.Settings("org.gnome.desktop.wm.preferences")
+        self.key_name = "focus-mode"
+
+        self.set_selection_mode(Gtk.SelectionMode.NONE)
+
+        # Needs other page elements to get margins too
+        # self.props.margin_left = 50
+        # self.props.margin_right = 50
+
+        row = Gtk.ListBoxRow()
+        hbox = Gtk.Box()
+        hbox.props.margin = 10
+        row.add(hbox)
+
+        vbox = Gtk.Box(orientation=Gtk.Orientation.VERTICAL)
+
+        lbl = Gtk.Label(_("Click to Focus"), xalign=0)
+        lbl.props.xalign = 0.0
+        desc = _("Windows are focused when they are clicked.")
+        lbl_desc = Gtk.Label()
+        lbl_desc.set_line_wrap(True)
+        lbl_desc.get_style_context().add_class("dim-label")
+        lbl_desc.set_markup("<span size='small'>"+GLib.markup_escape_text(desc)+"</span>")
+
+        self.check_click = Gtk.Image.new_from_icon_name("object-select-symbolic", Gtk.IconSize.SMALL_TOOLBAR);
+        self.check_click.set_no_show_all(True)
+        self.check_click.set_visible(self.settings[self.key_name] == "click")
+
+        vbox.pack_start(lbl, False, False, 0)
+        vbox.pack_start(lbl_desc, False, False, 0)
+        hbox.pack_start(vbox, False, False, 0)
+        hbox.pack_end(self.check_click, False, False, 0)
+
+        self.add(row)
+
+        row = Gtk.ListBoxRow()
+        hbox = Gtk.Box()
+        hbox.props.margin = 10
+        row.add(hbox)
+
+        vbox = Gtk.Box(orientation=Gtk.Orientation.VERTICAL)
+
+        lbl = Gtk.Label(_("Sloppy"), xalign=0)
+        lbl.props.xalign = 0.0
+        desc = _("Window is focused when hovered with the pointer. Windows remain focused when the desktop is hovered.")
+        lbl_desc = Gtk.Label()
+        lbl_desc.set_line_wrap(True)
+        lbl_desc.get_style_context().add_class("dim-label")
+        lbl_desc.set_markup("<span size='small'>"+GLib.markup_escape_text(desc)+"</span>")
+
+        self.check_sloppy = Gtk.Image.new_from_icon_name("object-select-symbolic", Gtk.IconSize.SMALL_TOOLBAR);
+        self.check_sloppy.set_no_show_all(True)
+        self.check_sloppy.set_visible(self.settings[self.key_name] == "sloppy")
+
+        vbox.pack_start(lbl, False, False, 0)
+        vbox.pack_start(lbl_desc, False, False, 0)
+        hbox.pack_start(vbox, False, False, 0)
+        hbox.pack_end(self.check_sloppy, False, False, 0)
+
+        self.add(row)
+
+        row = Gtk.ListBoxRow()
+        hbox = Gtk.Box()
+        hbox.props.margin = 10
+        row.add(hbox)
+
+        vbox = Gtk.Box(orientation=Gtk.Orientation.VERTICAL)
+
+        lbl = Gtk.Label(_("Secondary-Click"), xalign=0)
+        lbl.props.xalign = 0.0
+        desc = _("Window is focused when hovered with the pointer. Hovering the desktop removes focus from the previous window.")
+        lbl_desc = Gtk.Label()
+        lbl_desc.set_line_wrap(True)
+        lbl_desc.get_style_context().add_class("dim-label")
+        lbl_desc.set_markup("<span size='small'>"+GLib.markup_escape_text(desc)+"</span>")
+
+        self.check_mouse = Gtk.Image.new_from_icon_name("object-select-symbolic", Gtk.IconSize.SMALL_TOOLBAR);
+        self.check_mouse.set_no_show_all(True)
+        self.check_mouse.set_visible(self.settings[self.key_name] == "mouse")
+
+        vbox.pack_start(lbl, False, False, 0)
+        vbox.pack_start(lbl_desc, False, False, 0)
+        hbox.pack_start(vbox, False, False, 0)
+        hbox.pack_end(self.check_mouse, False, False, 0)
+
+        self.add(row)
+        self.connect('row-activated', self.on_row_clicked)
+
+    def on_row_clicked(self, box, row):
+        if row.get_index() == 0:
+            self.settings[self.key_name] = "click"
+            self.check_click.show()
+            self.check_sloppy.hide()
+            self.check_mouse.hide()
+        elif row.get_index() == 1:
+            self.settings[self.key_name] = "sloppy"
+            self.check_click.hide()
+            self.check_sloppy.show()
+            self.check_mouse.hide()
+        else:
+            self.settings[self.key_name] = "mouse"
+            self.check_click.hide()
+            self.check_sloppy.hide()
+            self.check_mouse.show()
+
 
 class ShowWindowButtons(GSettingsSwitchTweakValue):
 
@@ -42,7 +155,7 @@ class ShowWindowButtons(GSettingsSwitchTweakValue):
 
         if "close" in right:
             rsplit = right.split(",")
-            rsplit = [x for x in rsplit if x in ['appmenu', 'close', 'maximize', 'minimize']]
+            rsplit = [x for x in rsplit if x in ['appmenu', 'minimize', 'maximize', 'close']]
 
             if v:
                 rsplit.append(self.value)
@@ -55,14 +168,14 @@ class ShowWindowButtons(GSettingsSwitchTweakValue):
 
         else:
             rsplit = left.split(",")
-            rsplit = [x for x in rsplit if x in ['appmenu', 'close', 'maximize', 'minimize']]
+            rsplit = [x for x in rsplit if x in ['appmenu', 'minimize', 'maximize', 'close']]
 
             if v:
                 rsplit.append(self.value)
             else:
                 rsplit.remove(self.value)
 
-            rsplit.sort(key=lambda x: ["appmenu", "close", "maximize", "minimize"].index(x))
+            rsplit.sort(key=lambda x: ["close", "minimize", "maximize", "appmenu"].index(x))
 
             self.settings.set_string(self.key_name, ",".join(rsplit) + colon + right)
 
@@ -106,9 +219,17 @@ class PlaceWindowButtons(Gtk.Box, _GSettingsTweak):
     def on_button_toggled(self, v):
         val = self.settings.get_string(self.key_name)
         (left, colon, right) = val.partition(":")
-        left = ','.join(list(reversed(left.split(','))))
-        right = ','.join(list(reversed(right.split(','))))
-        self.settings.set_string(self.key_name, right + colon + left)
+
+        if "close" in left:
+            rsplit = left.split(",")
+            rsplit = [x for x in rsplit if x in ['appmenu', 'minimize', 'maximize', 'close']]
+            rsplit.sort(key=lambda x: ["appmenu", "minimize", "maximize", "close"].index(x))
+            self.settings.set_string(self.key_name, right + colon + ",".join(rsplit))
+        else:
+            rsplit = right.split(",")
+            rsplit = [x for x in rsplit if x in ['appmenu', 'minimize', 'maximize', 'close']]
+            rsplit.sort(key=lambda x: ["close", "minimize", "maximize", "appmenu"].index(x))
+            self.settings.set_string(self.key_name, ",".join(rsplit) + colon + left)
 
 class WindowScalingFactorTweak(Gtk.Box, Tweak):
     def __init__(self, **options):
@@ -181,8 +302,6 @@ class WindowScalingFactorTweak(Gtk.Box, Tweak):
         self._close()
         self._dialog.destroy()
 
-Focus =  GSettingsComboTweak(_("Focus Mode"), "org.gnome.desktop.wm.preferences", "focus-mode",
-      [("click", _("Click to Focus")), ("sloppy", _("Sloppy")), ("mouse", _("Mouse"))])
 depends_how = lambda x,kn: x.get_string(kn) in ("mouse", "sloppy")
 
 TWEAK_GROUPS = [
@@ -194,8 +313,9 @@ TWEAK_GROUPS = [
                         "org.gnome.desktop.wm.preferences",
                         "mouse-button-modifier",
                         [("disabled", _("Disabled")), ("<Alt>", "Alt"), ("<Super>", "Super")]),
-        Focus,
-        GSettingsSwitchTweak(_("Raise Windows When Focused"),"org.gnome.desktop.wm.preferences", "auto-raise", depends_on=Focus, depends_how=depends_how),
+        Title(_("Window Focus"), _("Click to Focus"), uid="title-theme"),
+        Focus(),
+        GSettingsSwitchTweak(_("Raise Windows When Focused"),"org.gnome.desktop.wm.preferences", "auto-raise", depends_on=Focus(), depends_how=depends_how),
         Title(_("Titlebar Actions"), "", uid="title-titlebar-actions"),
         GSettingsComboEnumTweak(_("Double-Click"),"org.gnome.desktop.wm.preferences", "action-double-click-titlebar"),
         GSettingsComboEnumTweak(_("Middle-Click"),"org.gnome.desktop.wm.preferences", "action-middle-click-titlebar"),
